#!/usr/bin/env python3
# Straightforward max-likelihood solution
# Time complexity is O(max_infected * max_queries * log(N))
# But constant factor is bad.
import math
MAX_QUERIES = 50
MIN_INFECTED = 100
MAX_INFECTED = 5000000
N = 10**7

x = []
res = []
p = [1.0/(MAX_INFECTED-MIN_INFECTED+1) if i >= MIN_INFECTED else 0 for i in range(MAX_INFECTED+1)]

# we want to do a lot of evaluations of pow(1-i/N, k) for various i and k
# exp() is >2x faster than pow(), so precompute all logs
lni = [math.log(1-i/N) for i in range(MAX_INFECTED+1)]

def prob_yes(k):
    return sum(p[i] * math.exp(lni[i]*k) for i in range(MIN_INFECTED, MAX_INFECTED+1))

def guess_k():
    l = r = q = best_k = best_q = 0
    for k in range(MIN_INFECTED, MAX_INFECTED+1):
        while r <= min(11*k//10, MAX_INFECTED):
            q += p[r]
            r += 1
        while l < (9*k+9)//10:
            q -= p[l]
            l += 1
        if q > best_q:
            best_k = k
            best_q = q
    return best_k

for _ in range(MAX_QUERIES):
    lo = 0
    hi = N // MIN_INFECTED
    while hi-lo > 1:
        k = (lo+hi)//2
        z = prob_yes(k)
        if z > 0.5: lo = k
        else: hi = k
    k = hi
    print('test', k)
    res = int(input())
    scale = 0.0
    for i in range(MIN_INFECTED, MAX_INFECTED+1):
        p[i] *= 1-math.exp(lni[i]*k) if res else math.exp(lni[i]*k)
        scale += p[i]
    for i in range(MIN_INFECTED, MAX_INFECTED+1):
        p[i] /= scale
        
print('estimate', guess_k())
